FfiMessageStoreFactory

Trait FfiMessageStoreFactory 

pub trait FfiMessageStoreFactory {
    // Required method
    fn as_ffi_ptr(&self) -> FixMessageStoreFactory_t;
}
Object can be converted as a foreign object representing a MessageStore.

Required Methods

fn as_ffi_ptr(&self) -> FixMessageStoreFactory_t

Get a representation of the message store as a FFI pointer.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors