FieldMap

Trait FieldMap 

pub trait FieldMap {
    // Required methods
    fn get_field(&self, tag: i32) -> Option<String>;
    fn set_field<V: IntoFixValue>(
        &mut self,
        tag: i32,
        value: V,
    ) -> Result<(), QuickFixError>;
    fn remove_field(&mut self, tag: i32) -> Result<(), QuickFixError>;
    fn add_group(&mut self, group: &Group) -> Result<(), QuickFixError>;
    fn clone_group(&self, index: i32, tag: i32) -> Option<Group>;
}
Stores and organizes a collection of Fields.

This is the basis for a message, header, and trailer. This collection class uses a sorter to keep the fields in a particular order.

Required Methods

fn get_field(&self, tag: i32) -> Option<String>

Get field value from its tag number.

fn set_field<V: IntoFixValue>( &mut self, tag: i32, value: V, ) -> Result<(), QuickFixError>

Set field value for a given tag number.

fn remove_field(&mut self, tag: i32) -> Result<(), QuickFixError>

Remove a field from collection.

fn add_group(&mut self, group: &Group) -> Result<(), QuickFixError>

Add a new group to storage and update count.

fn clone_group(&self, index: i32, tag: i32) -> Option<Group>

Clone group part for a given tag and group index.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors