pub trait FfiMessageStoreFactory {
// Required method
fn as_ffi_ptr(&self) -> FixMessageStoreFactory_t;
}Expand description
Object can be converted as a foreign object representing a MessageStore.
Required Methods
Sourcefn as_ffi_ptr(&self) -> FixMessageStoreFactory_t
fn as_ffi_ptr(&self) -> FixMessageStoreFactory_t
Get a representation of the message store as a FFI pointer.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".